@@ -6,6 +6,7 @@ Currently help understanding of :
 """
 
 import sys
+from textwrap import dedent
 
 from astroid import MANAGER, AsStringRegexpPredicate, UseInferenceDefault, inference_tip, YES
 from astroid import exceptions
@@ -14,6 +15,49 @@ from astroid.builder import AstroidBuilder
 
 MODULE_TRANSFORMS = {}
 PY3K = sys.version_info > (3, 0)
+PY33 = sys.version_info >= (3, 3)
+
+# general function
+
+def infer_func_form(node, base_type, context=None):
+    """Specific inference function for namedtuple or Python 3 enum. """
+    def infer_first(node):
+        try:
+            value = node.infer(context=context).next()
+            if value is YES:
+                raise UseInferenceDefault()
+            else:
+                return value
+        except StopIteration:
+            raise InferenceError()
+
+    # node is a CallFunc node, class name as first argument and generated class
+    # attributes as second argument
+    if len(node.args) != 2:
+        # something weird here, go back to class implementation
+        raise UseInferenceDefault()
+    # namedtuple or enums list of attributes can be a list of strings or a
+    # whitespace-separate string
+    try:
+        name = infer_first(node.args[0]).value
+        names = infer_first(node.args[1])
+        try:
+            attributes = names.value.replace(',', ' ').split()
+        except AttributeError:
+            attributes = [infer_first(const).value for const in names.elts]
+    except (AttributeError, exceptions.InferenceError):
+        raise UseInferenceDefault()
+    # we want to return a Class node instance with proper attributes set
+    class_node = nodes.Class(name, 'docstring')
+    class_node.parent = node.parent
+    # set base class=tuple
+    class_node.bases.append(base_type)
+    # XXX add __init__(*attributes) method
+    for attr in attributes:
+        fake_node = nodes.EmptyNode()
+        fake_node.parent = class_node
+        class_node.instance_attrs[attr] = [fake_node]
+    return class_node, name, attributes
 
 
 # module specific transformation functions #####################################
@@ -58,7 +102,7 @@ class defaultdict(dict):
 
 class deque(object):
     maxlen = 0
-    def __init__(iterable=None, maxlen=None): pass
+    def __init__(self, iterable=None, maxlen=None): pass
     def append(self, x): pass
     def appendleft(self, x): pass
     def clear(self): pass
@@ -148,24 +192,40 @@ class ParseResult(object):
 def subprocess_transform(module):
     if PY3K:
         communicate = (bytes('string', 'ascii'), bytes('string', 'ascii'))
+        init = """
+    def __init__(self, args, bufsize=0, executable=None,
+                 stdin=None, stdout=None, stderr=None,
+                 preexec_fn=None, close_fds=False, shell=False,
+                 cwd=None, env=None, universal_newlines=False,
+                 startupinfo=None, creationflags=0, restore_signals=True,
+                 start_new_session=False, pass_fds=()):
+        pass
+        """
     else:
         communicate = ('string', 'string')
-    fake = AstroidBuilder(MANAGER).string_build('''
-
-class Popen(object):
-    returncode = pid = 0
-    stdin = stdout = stderr = file()
-
+        init = """
     def __init__(self, args, bufsize=0, executable=None,
                  stdin=None, stdout=None, stderr=None,
                  preexec_fn=None, close_fds=False, shell=False,
                  cwd=None, env=None, universal_newlines=False,
                  startupinfo=None, creationflags=0):
         pass
+        """
+    if PY33:
+        wait_signature = 'def wait(self, timeout=None)'
+    else:
+        wait_signature = 'def wait(self)'
+    fake = AstroidBuilder(MANAGER).string_build('''
+
+class Popen(object):
+    returncode = pid = 0
+    stdin = stdout = stderr = file()
+
+    %(init)s
 
     def communicate(self, input=None):
-        return %r
-    def wait(self):
+        return %(communicate)r
+    %(wait_signature)s:
         return self.returncode
     def poll(self):
         return self.returncode
@@ -175,7 +235,9 @@ class Popen(object):
         pass
     def kill(self):
         pass
-   ''' % (communicate, ))
+   ''' % {'init': init,
+          'communicate': communicate,
+          'wait_signature': wait_signature})
 
     for func_name, func in fake.locals.items():
         module.locals[func_name] = func
@@ -192,43 +254,8 @@ MODULE_TRANSFORMS['subprocess'] = subprocess_transform
 
 def infer_named_tuple(node, context=None):
     """Specific inference function for namedtuple CallFunc node"""
-    def infer_first(node):
-        try:
-            value = node.infer().next()
-            if value is YES:
-                raise UseInferenceDefault()
-            else:
-                return value
-        except StopIteration:
-            raise InferenceError()
-
-    # node is a CallFunc node, class name as first argument and generated class
-    # attributes as second argument
-    if len(node.args) != 2:
-        # something weird here, go back to class implementation
-        raise UseInferenceDefault()
-    # namedtuple list of attributes can be a list of strings or a
-    # whitespace-separate string
-    try:
-        name = infer_first(node.args[0]).value
-        names = infer_first(node.args[1])
-        try:
-            attributes = names.value.split()
-        except AttributeError:
-            attributes = [infer_first(const).value for const in names.elts]
-    except (AttributeError, exceptions.InferenceError):
-        raise UseInferenceDefault()
-    # we want to return a Class node instance with proper attributes set
-    class_node = nodes.Class(name, 'docstring')
-    class_node.parent = node.parent
-    # set base class=tuple
-    class_node.bases.append(nodes.Tuple._proxied)
-    # XXX add __init__(*attributes) method
-    for attr in attributes:
-        fake_node = nodes.EmptyNode()
-        fake_node.parent = class_node
-        class_node.instance_attrs[attr] = [fake_node]
-
+    class_node, name, attributes = infer_func_form(node, nodes.Tuple._proxied,
+                                                   context=context)
     fake = AstroidBuilder(MANAGER).string_build('''
 class %(name)s(tuple):
     def _asdict(self):
@@ -248,5 +275,51 @@ class %(name)s(tuple):
     # we use UseInferenceDefault, we can't be a generator so return an iterator
     return iter([class_node])
 
+def infer_enum(node, context=None):
+    """ Specific inference function for enum CallFunc node. """
+    enum_meta = nodes.Class("EnumMeta", 'docstring')
+    class_node = infer_func_form(node, enum_meta, context=context)[0]
+    return iter([class_node.instanciate_class()])
+
+def infer_enum_class(node, context=None):
+    """ Specific inference for enums. """
+    names = set(('Enum', 'IntEnum', 'enum.Enum', 'enum.IntEnum'))
+    for basename in node.basenames:
+        # TODO: doesn't handle subclasses yet.
+        if basename not in names:
+            continue
+        if node.root().name == 'enum':
+            # Skip if the class is directly from enum module.
+            break
+        for local, values in node.locals.items():
+            if any(not isinstance(value, nodes.AssName)
+                   for value in values):
+                continue
+            parent = values[0].parent
+            real_value = parent.value
+            new_targets = []
+            for target in parent.targets:
+                # Replace all the assignments with our mocked class.
+                classdef = dedent('''
+                class %(name)s(object):
+                    @property
+                    def value(self):
+                        return %(value)s
+                    @property
+                    def name(self):
+                        return %(name)r
+                    %(name)s = %(value)s
+                ''' % {'name': target.name,
+                       'value': real_value.as_string()})
+                fake = AstroidBuilder(MANAGER).string_build(classdef)[target.name]
+                fake.parent = target.parent
+                new_targets.append(fake.instanciate_class())
+            node.locals[local] = new_targets
+        break
+    return node
+
 MANAGER.register_transform(nodes.CallFunc, inference_tip(infer_named_tuple),
                            AsStringRegexpPredicate('namedtuple', 'func'))
+MANAGER.register_transform(nodes.CallFunc, inference_tip(infer_enum),
+                           AsStringRegexpPredicate('Enum', 'func'))
+MANAGER.register_transform(nodes.Class, infer_enum_class)
